<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="40"/>
        <source>About</source>
        <translation>Относно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>Thanks</source>
        <translation>Благодарности</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Help us</source>
        <translation>Помогнете ни</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="99"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>е приложение за различни платформи за бързо създаване на екранни снимки на вашия работен плот.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="101"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>То е леко и мощно приложение, създадено с Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="33"/>
        <source>using Qt %1</source>
        <translation>използва Qt %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="104"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>Уеб сайт - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="107"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>Лицензирано под &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="111"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Авторско право &amp;копиране; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
        <translation>Авторски права &amp;копиране; 2013-2025, екипът на LXQt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Можете да се присъедините към нас и да ни помогнете, ако искате. Това е покана, ако харесвате това приложение.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>Какво можете да направите?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>да преведете ScreenGrab на други езици</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>да дадете предложения за следващите издания</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>да докладвате грешки и проблеми</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>Проследяване на грешки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source>Special thanks to:</source>
        <translation>Специални благодарности на:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>for creating ScreenGrab</source>
        <translation>за създаването на ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source>for supporting wlr screencopy protocol</source>
        <translation>за поддръжката на протокола за копиране на екрана WLR</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>Директория %1 не съществува. Искате ли да я създадете?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
        <source>Warning</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
        <source>Select directory</source>
        <translation>Избиране на директория</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Искате ли да възстановите настройките по подразбиране?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
        <source>Example: </source>
        <translation>Например: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Този клавиш вече се използва в ScreenGrab! Моля, изберете друг.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
        <source>This key is not supported on your system!</source>
        <translation>Този клавиш не се поддържа от вашата система!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>е приложение за различни платформи за бързо създаване на екранни снимки на вашия работен плот.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Създаване на снимка на целия екран</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Take a screenshot of the active window</source>
        <translation>Създаване на снимка на активния прозорец</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="78"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Създаване на снимка на област от екрана</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="82"/>
        <source>Run the application with a hidden main window</source>
        <translation>Стартиране на приложението със скрит главен прозорец</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="85"/>
        <source>Save screenshot and exit, without showing window</source>
        <translation>Запазване на екранната снимка и изход, без показване на прозорец</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="575"/>
        <source>Saved</source>
        <translation>Снимката е запазена</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="575"/>
        <source>Saved to </source>
        <translation>Снимката е запазена в </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="597"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Името на записания файл се копира в клипборда</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="603"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Пътят на записания файл се копира в клипборда</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="626"/>
        <source>Copied</source>
        <translation>Копиран</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="626"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Снимката е копирана в клипборда</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>Снимка на екрана - ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
        <source>Screen:</source>
        <translation>Екран:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
        <source>Type of screenshot</source>
        <translation>Вид на снимката на екрана</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="122"/>
        <source>Full screen</source>
        <translation>Пълен екран</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="127"/>
        <source>Window</source>
        <translation>Прозорец</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="132"/>
        <source>Screen area</source>
        <translation>Избрана област</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="137"/>
        <source>Last selected area</source>
        <translation>Последно избрана област</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="167"/>
        <source>Delay:</source>
        <translation>Забавяне:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="180"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Забавяне в секунди преди снимане</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="183"/>
        <source>None</source>
        <translation>Не</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="186"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="245"/>
        <source>Zoom area around mouse</source>
        <translation>Увеличаване на областта около мишката</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="252"/>
        <source>No window decoration</source>
        <translation>Без декорации на прозорец</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="259"/>
        <source>Include mouse pointer</source>
        <translation>Включва и показалеца на мишката</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="291"/>
        <source>toolBar</source>
        <translation>Лента с инструменти</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
        <source>New</source>
        <translation>Създаване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>Save</source>
        <translation>Запазване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>About</source>
        <translation>Относно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <source>Quit</source>
        <translation>Изход</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="358"/>
        <source>Screenshot </source>
        <translation>Снимка на екрана </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="362"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Щракнете двукратно, за да отворите снимката в приложението за преглед на изображения по подразбиране</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="540"/>
        <source>Hide</source>
        <translation>Скриване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="547"/>
        <source>Show</source>
        <translation>Показване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="616"/>
        <source>%1 Files</source>
        <translation>%1 файла</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="638"/>
        <source>Save As...</source>
        <translation>Запазване като...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="148"/>
        <source>Click and drag to draw a rectangle,
double click or press Enter
to take a screenshot,
or press Escape to cancel.</source>
        <translation>Щракнете и плъзнете, за да нарисувате правоъгълник,
щракнете два пъти или натиснете Enter
да направите екранна снимка,
или натиснете Escape за отмяна.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="245"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Щракнете и плъзнете, за да начертаете правоъгълник,
щракнете с десния бутон, за да се поберат до ръбовете
щракнете двукратно или натиснете Enter,
за да направите екранна снимка.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="305"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 пиксела </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Редактиране във външно приложение</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Редактиране в...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>Относно Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>Затваряне</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="35"/>
        <source>Main</source>
        <translation>Основни</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="40"/>
        <source>Advanced</source>
        <translation>Разширени</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="45"/>
        <source>System tray</source>
        <translation>Системна област на известяване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="50"/>
        <source>Shortcuts</source>
        <translation>Клавишни комбинации</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="74"/>
        <source>Default save directory</source>
        <translation>Директория по подразбиране за запазване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="80"/>
        <source>Path to default selection dir for saving</source>
        <translation>Път до избраната директория за запазване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="93"/>
        <source>Browse filesystem</source>
        <translation>Преглеждане на файловата система</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="96"/>
        <source>Browse</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="106"/>
        <source>Default file</source>
        <translation>Файл по подразбиране</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="119"/>
        <source>Name:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="126"/>
        <source>Default filename</source>
        <translation>Име на файл по подразбиране</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="137"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="150"/>
        <source>Default saving image format</source>
        <translation>Формат по подразбиране</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="169"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Копиране на пътя на файла в клипборда при запазване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="183"/>
        <source>Do not copy</source>
        <translation>Без копиране</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="188"/>
        <source>Copy file name only</source>
        <translation>Копиране само името на файла</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="193"/>
        <source>Copy full file path</source>
        <translation>Копиране на целия път на файла</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="203"/>
        <source>Image quality</source>
        <translation>Качество на изображение</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="209"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Качество на изображение (1 - малък файл, 100 - високо качество)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="274"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Внасяне на текущата дата и час в името на запазения файл</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="277"/>
        <source>Insert current date and time in file name</source>
        <translation>Внасяне на текущата дата и час в името на файл</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="286"/>
        <source>Template: </source>
        <translation>Шаблон: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="311"/>
        <source>Example: </source>
        <translation>Например: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="321"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Автоматично запазване на снимките в процеса на снимане</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="324"/>
        <source>Autosave screenshot</source>
        <translation>Автоматично запазване на снимките</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="336"/>
        <source>Save first screenshot</source>
        <translation>Запазване на първата снимка</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="345"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Позволяване на изпълнение на множество копия на ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="348"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Разрешаване на множество инстанции на ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="355"/>
        <source>Open in external viewer on double click</source>
        <translation>Отваряне във външна програма за преглед при двойно щракване</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="358"/>
        <source>Enable external viewer</source>
        <translation>Активиране на външна програма за преглед</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="365"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Ако това не е отметнато, избраната област
може да стане по-голяма, за да се побере към външните краища</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="369"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Напасване към краищата на избраната област при щракване с десния бутон</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="376"/>
        <source>With multiple screens</source>
        <translation>С множество екрани</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="379"/>
        <source>Remember last selected screen in next session</source>
        <translation>Запомняне на последният избран екран в следващата сесия</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="386"/>
        <source>Notify on saving and copying</source>
        <translation>Уведомяване при запазване и копиране</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="395"/>
        <source>Duration:</source>
        <translation>Продължителност:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="462"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Показване на ScreenGrab в системната област</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="402"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="469"/>
        <source>Minimize to tray on click close button</source>
        <translation>Минимизиране в системната област при щракване върху бутона за затваряне</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="472"/>
        <source>Minimize to tray when closing</source>
        <translation>Минимизиране в системната област при затваряне</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="511"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source>Shortcut</source>
        <translation>Клавишна комбинация</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="521"/>
        <source>New screen</source>
        <translation>Нов екран</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="526"/>
        <source>Save screen</source>
        <translation>Запазване на екрана</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="531"/>
        <source>Copy screen</source>
        <translation>Копиране на екрана</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="541"/>
        <source>Quit</source>
        <translation>Изход</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="551"/>
        <source>Selected shortcut:</source>
        <translation>Избрана клавишна комбинация:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Not defined</source>
        <translation>Не е зададено</translation>
    </message>
</context>
</TS>
